﻿using System;
using System.Drawing;

using Foundation;
using UIKit;
using Syncfusion.SfChart.iOS;
using CoreGraphics;

namespace ChartSample
{
	public partial class ChartSampleViewController : UIViewController
	{
		static bool UserInterfaceIdiomIsPhone {
			get { return UIDevice.CurrentDevice.UserInterfaceIdiom == UIUserInterfaceIdiom.Phone; }
		}

		public ChartSampleViewController (IntPtr handle) : base (handle)
		{
		}

		public override void DidReceiveMemoryWarning ()
		{
			base.DidReceiveMemoryWarning ();
		}

		#region View lifecycle

		public override void ViewDidLoad ()
		{
			base.ViewDidLoad ();

			SFChart chart                         = new SFChart ();
			chart.EdgeInsets 					  = new UIEdgeInsets (20,10,10,10);
			chart.Frame                           = this.View.Frame;
			SFNumericalAxis primaryAxis     	  = new SFNumericalAxis ();
			chart.PrimaryAxis                     = primaryAxis;
			SFNumericalAxis secondaryAxis 		  = new SFNumericalAxis ();
			chart.SecondaryAxis                   = secondaryAxis;

			ChartDataModel dataModel              = new ChartDataModel ();
			chart.DataSource                      = dataModel as SFChartDataSource;

			this.View.AddSubview (chart);
		}

		public override void ViewWillAppear (bool animated)
		{
			base.ViewWillAppear (animated);
		}

		public override void ViewDidAppear (bool animated)
		{
			base.ViewDidAppear (animated);
		}

		public override void ViewWillDisappear (bool animated)
		{
			base.ViewWillDisappear (animated);
		}

		public override void ViewDidDisappear (bool animated)
		{
			base.ViewDidDisappear (animated);
		}

		#endregion
	}
		
	public class ChartDataModel : SFChartDataSource
	{
		NSMutableArray DataPoints;
		NSMutableArray DataPoints1;
		NSMutableArray DataPoints2;

		public ChartDataModel ()
		{
			DataPoints = new NSMutableArray ();
			DataPoints1 = new NSMutableArray ();
			DataPoints2 = new NSMutableArray ();
			AddDataPointsForChart("2010", 6,54,14);
			AddDataPointsForChart("2011", 15,24,54);
			AddDataPointsForChart("2012", 35,53,23);
			AddDataPointsForChart("2013", 65,63,53);
			AddDataPointsForChart("2014", 75,35,25);
		}

		void AddDataPointsForChart (String XValue, Double YValue, Double YValue1, Double YValue2)
		{
			DataPoints.Add (new SFChartDataPoint (NSObject.FromObject (XValue), NSObject.FromObject(YValue)));
			DataPoints1.Add (new SFChartDataPoint (NSObject.FromObject (XValue), NSObject.FromObject(YValue1)));
			DataPoints2.Add (new SFChartDataPoint (NSObject.FromObject (XValue), NSObject.FromObject(YValue2)));
		}

		//[Export ("numberOfSeriesInChart:")]
		public override nint NumberOfSeriesInChart (SFChart chart)
		{
			return 3; 
		}

		//[Export ("chart:seriesAtIndex:")]
		public override SFSeries GetSeries (SFChart chart, nint index)
		{
			if (index == 0) {
				SFLineSeries series = new SFLineSeries ();
				//Solid LineSeries
				series.LineWidth = 6;
				return series;
			} else if (index == 1) {
				SFLineSeries series = new SFLineSeries ();
				//Dotted LineSeries
				NSObject[] dashes = new NSObject[2];
				dashes [0] = (NSNumber)2;
				dashes [1] = (NSNumber)2;
				series.Dashes = NSArray.FromObjects(dashes);
				return series;
			} else {
				SFLineSeries series = new SFLineSeries ();
				//LongDash LineSeries
				NSObject[] dashes = new NSObject[2];
				dashes [0] = (NSNumber)10;
				dashes [1] = (NSNumber)2;
				series.Dashes = NSArray.FromObjects(dashes);
				return series;
			}
		}

		//[Export ("chart:dataPointAtIndex:forSeriesAtIndex:")]
		public override SFChartDataPoint GetDataPoint (SFChart chart, nint index, nint seriesIndex)
		{
			if (seriesIndex == 0)
				return DataPoints.GetItem<SFChartDataPoint> ((nuint)index);
			else if (seriesIndex == 1)
				return DataPoints1.GetItem<SFChartDataPoint> ((nuint)index);
			else
				return DataPoints2.GetItem<SFChartDataPoint> ((nuint)index);
		}

		//[Export ("chart:numberOfDataPointsForSeriesAtIndex:")]
		public override nint GetNumberOfDataPoints (SFChart chart, nint index)
		{
			if(index == 0)
				return (int)DataPoints.Count;
			else if(index ==1)
				return (int)DataPoints1.Count;
			else 
				return (int)DataPoints2.Count;
		}
	}
}
